"""
django-handy-helpers library
----------------------------
A collection of handy utilities to support django operations.
:copyright: (c) 2018 by David Slusser
:license: GPL-3.0. See LICENSE for more details
"""

__title__ = "django-handyhelpers"
__version__ = "0.3.41"
__author__ = "David Slusser"
__email__ = "dbslusser@gmail.com"
__license__ = "GPL-3.0"
__copyright__ = "Copyright 2018 David Slusser"
